@@ -36,7 +36,7 @@ except:
     isHildon=False
 
 
-version="0.3"
+version="0.4"
 
 if not isHildon:
     class  hildon:
@@ -315,7 +315,7 @@ class MainPanel(Panel):
         while iter!=None:
             if store[iter][0]==record.id:
                 break
-            iter=self.iter_next(iter)
+            iter=store.iter_next(iter)
         if iter:
             self.treeview.get_selection().select_iter(iter)
             self.editCb()
@@ -329,6 +329,7 @@ class MainPanel(Panel):
         (dummy, iter)=selection.get_selected()
         if iter!=None:
             recordId=store[iter][0]
+            #print "Editing",store[iter][1],"index",recordId
             record=store.records[recordId]
             self.main.editPanel.activate(record)
 
@@ -346,10 +347,7 @@ class MainPanel(Panel):
             self.dialog.destroy()
             self.dialog=None
             if result==gtk.RESPONSE_YES:
-                store=self.main.store
-                recordId=store[iter][0]
-                store.deleteRecord(recordId)
-                store.remove(iter)
+                self.main.store.deleteRecord(iter)
                 self.main.save()
 
 
